@@ -3,9 +3,9 @@ const test     = require('tap').test
 
 test('asyncworker', function (t) {
   var worker = bindings('asyncworker').a
-  t.type(worker, 'function')
-  var ticks  = 0
+    , ticks  = 0
     , called = false
+  t.type(worker, 'function')
   function tick () {
     ticks++
     if (!called)
@@ -14,7 +14,7 @@ test('asyncworker', function (t) {
   setTimeout(tick, 0)
   worker(200, function () {
     called = true
-    t.ok(ticks > 50, 'got plenty of ticks! (' + ticks + ')')
+    t.ok(ticks > 12, 'got plenty of ticks! (' + ticks + ')')
     t.end()
   })
-})
\ No newline at end of file
+})
